@@ -1,6 +1,6 @@
-__version__ = "7.1.2"
+__version__ = "7.2.0"
 
 from .arg import AutoName, Expander, Param, Positional
 from .config import Config
-from .errors import Err
+from .errors import Err, Result
 from .types import ParamType
